@@ -2,29 +2,33 @@
 #define CAMMAINWINDOW_HPP
 
 #ifdef HAVE_CONFIG_H
-#incude <config.h>
+#include "config.h"
 #endif
 
 #include <qlist.h>
 #include <qmainwindow.h>
-#include <qworkspace.h> 
-
-#if HAVE_CONFIG_H
-#include "config.h"
-#endif
+#include <qworkspace.h>
 
 class CCamStreamMainWindow: public QMainWindow
 {
    Q_OBJECT
 private:
-   QWorkspace *Workspace;
-   
-private slots:
+   QWorkspace *m_pWorkspace;
+
    void CloseAll();
 
-   // Menu options 
+private slots:
+   void Quit();
+
+   // Menu options
    void FileOpenNewViewer();
-   
+
+   // Misc
+   void ShowTracer();
+
+protected:
+  void closeEvent(QCloseEvent *);
+
 public:
    CCamStreamMainWindow();
    ~CCamStreamMainWindow();
