@@ -2,7 +2,7 @@
 #define CAMWINDOW_HPP
 
 #ifdef HAVE_CONFIG_H
-#incude <config.h>
+#include "config.h"
 #endif
 
 #include <qmainwindow.h>
@@ -18,7 +18,7 @@ protected:
 
 public:
    virtual ~CCamWindow();
-};   
+};
 
 
 
