@@ -2,7 +2,7 @@
 #define FTPPUT_HPP
 
 #ifdef HAVE_CONFIG_H
-#incude <config.h>
+#include "config.h"
 #endif
 
 #include <qapplication.h>
@@ -36,7 +36,7 @@ private:
    
 private slots:
    void ProcessNextCommand();
-   void Action(int, int);
+   void Action(int cmd, int status, int result, const QString &resp_string);
    void Progress(int);
 
 public:
