@@ -11,7 +11,7 @@ class CSnapshotSettingsDlg: public CSnapshotSettings
 {
    Q_OBJECT
 private:
-   struct SVideoOptions *pVOpts;
+   struct CVideoOptions *pVOpts;
    CFTPSettings *pFTPSettings;
    QColor TextColor;
    QFont TextFont;
@@ -24,8 +24,8 @@ protected:
    void ClickedFont();
    void ClickedFTP();
 
-public:   
-   CSnapshotSettingsDlg(struct SVideoOptions *opts);
+public:
+   CSnapshotSettingsDlg(struct CVideoOptions *opts, QWidget *parent = 0, const char *name = 0);
 
 signals:
    void FTPSettingsUpdated();
