@@ -8,14 +8,14 @@ class CImagePanelRGB: public CCamPanel
 {
    Q_OBJECT
 private:
-   CVideoDevice *pVideo;
+   CVideoDevice *m_pVideo;
 
 private slots:
    void UpdateImage();
 
 public:
    CImagePanelRGB(CVideoDevice *pVideo, QWidget *parent = 0, const char *name = 0);
-   
+
    // overloaded from QWidget
    void hideEvent(QHideEvent *);
    void showEvent(QShowEvent *);
