@@ -24,20 +24,30 @@ CImagePanelYUV::CImagePanelYUV(CVideoDevice *video, QWidget *parent, const char
 	: CCamPanel("image.yuv", "Video image YUV", YUV420, TRUE, parent, name)
 {
    assert(video != NULL);
-   pVideo = video;
-   SetSize(pVideo->GetSize());
-   connect(pVideo, SIGNAL(Resized(const QSize &)), this, SLOT(SetSize(const QSize &)));
-   connect(pVideo, SIGNAL(Notify()), this, SLOT(UpdateImage()));
+   m_pVideo = video;
+   SetSize(m_pVideo->GetSize());
+   connect(m_pVideo, SIGNAL(SizeChanged(const QSize &)), this, SLOT(SetSize(const QSize &)));
+   connect(m_pVideo, SIGNAL(FrameReady()), this, SLOT(UpdateImage()));
 }
 
-
 // private
 
 void CImagePanelYUV::UpdateImage()
 {
-   ImgY = *pVideo->GetY();
-   ImgU = *pVideo->GetU();
-   ImgV = *pVideo->GetV();
+   CVideoFrame *frame = 0;
+
+   frame = m_pVideo->GetLatestVideoFrame();
+   if (frame == 0) {
+     ImgY.reset();
+     ImgU.reset();
+     ImgV.reset();
+   }
+   else {
+     ImgY = frame->GetY()->copy();
+     ImgU = frame->GetU()->copy();
+     ImgV = frame->GetV()->copy();
+   }
+   delete frame;
    update();
 }
 
@@ -52,7 +62,7 @@ void CImagePanelYUV::hideEvent(QHideEvent *e)
    qDebug("CImagePanelYUV::hideEvent()");
 #endif   
    //CCamPanel::SetVisibility(new_vis);
-   pVideo->EnableYUV(FALSE);
+   m_pVideo->DisableYUV();
    QWidget::hideEvent(e);
 }
 
@@ -60,9 +70,7 @@ void CImagePanelYUV::showEvent(QShowEvent *e)
 {
 #if TRACE_PANELSIGNALS
    qDebug("CImagePanelYUV::showEvent()");
-#endif   
-   pVideo->EnableYUV(TRUE);
+#endif
+   m_pVideo->EnableYUV();
    QWidget::showEvent(e);
 }
-
-
