@@ -8,13 +8,13 @@ class CImagePanelYUV: public CCamPanel
 {
    Q_OBJECT
 private:
-   CVideoDevice *pVideo;
+   CVideoDevice *m_pVideo;
 
 private slots:
    void UpdateImage();
 
 public:
-   CImagePanelYUV(CVideoDevice *pVideo, QWidget *parent = 0, const char *name = 0);
+   CImagePanelYUV(CVideoDevice *video, QWidget *parent = 0, const char *name = 0);
    
    // overloaded from QWidget
    void hideEvent(QHideEvent *);
