@@ -1,6 +1,3 @@
-#define __ASSEMBLY__
-#include <linux/linkage.h>
-
 #define Number 8(%ebp)
 #define Dst    12(%ebp)
 #define Src1   16(%ebp)
